@@ -20,8 +20,8 @@ class Accountant:
         self.ledger = LedgerClient(ledger_host="http://ledger-service-dev-1.local-dev:3000/")
 
         log.info("---------Initialising-------------")
-        log.info("Bank Account Number: ", self.bank_account['account_id'])
-        log.info("Cash Book: ", self.DEFAULT_CASH_BOOK_ID)
+        log.info(f"Bank Account Number:  {self.bank_account['account_id']}")
+        log.info(f"Cash Book:  {self.DEFAULT_CASH_BOOK_ID}")
 
     def get_book(self):
         log.info("---------Get Book----------")
@@ -153,9 +153,8 @@ class Accountant:
     def create_book(account_id: str):
         log.info("---------New_ledger-------------")
         ledger = LedgerClient(ledger_host="http://ledger-service-dev-1.local-dev:3000/")
-        block_book_id = ledger.create_book(name=f"{account_id}_block_book",
-                                                min_balance="-100")
-        main_book_id = ledger.create_book(name=f"{account_id}_main_book", min_balance="-100")
+        block_book_id = ledger.create_book(name=f"{account_id}_block_book", min_balance=0)
+        main_book_id = ledger.create_book(name=f"{account_id}_main_book", min_balance=0)
         new_books = {
             'main_balance': {'name': main_book_id['name'],
                              'id': main_book_id['id']},
